@@ -8,10 +8,13 @@ I borrowed test values and and conventions from Inkscape's `inkek.units.py`.
 :author: Shay Hill
 :created: 2023-02-12
 """
+
+from __future__ import annotations
+
 import dataclasses
 import enum
 import re
-from typing import Optional, Union
+from typing import Union
 
 from svg_ultralight.string_conversion import format_number
 
@@ -23,7 +26,6 @@ _UPC = 96 / 2.54
 
 
 class Unit(enum.Enum):
-
     """SVG Units of measurement.
 
     Value is (unit conversion, unit specifier)
@@ -57,7 +59,6 @@ MeasurementArg = Union[
     Unit,
 ]
 
-
 _UNIT_SPECIFIER2UNIT = {x.value[0]: x for x in Unit}
 
 _UNIT_SPECIFIERS = [x.value[0] for x in Unit]
@@ -96,7 +97,7 @@ def _parse_unit(measurement_arg: MeasurementArg) -> tuple[float, Unit]:
 
     """
     failure_msg = f"Cannot parse value and unit from {measurement_arg}"
-    unit: Union[str, Unit]
+    unit: str | Unit
     try:
         if isinstance(measurement_arg, tuple):
             number, unit = float(measurement_arg[0]), measurement_arg[1]
@@ -124,7 +125,6 @@ def _parse_unit(measurement_arg: MeasurementArg) -> tuple[float, Unit]:
 
 @dataclasses.dataclass
 class Measurement:
-
     """Measurement with unit of measurement.
 
     Converts to and stores the value in user units. Also retains the input units so
@@ -143,7 +143,7 @@ class Measurement:
         value, self.native_unit = _parse_unit(measurement_arg)
         self.value = value * self.native_unit.value[1]
 
-    def get_value(self, unit: Optional[Unit] = None) -> float:
+    def get_value(self, unit: Unit | None = None) -> float:
         """Get the measurement in the specified unit.
 
         :param unit: optional unit to convert to
@@ -158,7 +158,7 @@ class Measurement:
             unit = _UNIT_SPECIFIER2UNIT[unit]
         return self.value / unit.value[1]
 
-    def get_tuple(self, unit: Optional[Unit] = None) -> tuple[float, Unit]:
+    def get_tuple(self, unit: Unit | None = None) -> tuple[float, Unit]:
         """Get the measurement as a tuple of value and unit.
 
         :param unit: optional unit to convert to
@@ -166,7 +166,7 @@ class Measurement:
         """
         return self.get_value(unit), unit or Unit.USER
 
-    def get_str(self, unit: Optional[Unit] = None) -> str:
+    def get_str(self, unit: Unit | None = None) -> str:
         """Get the measurement in the specified unit as a string.
 
         :param optional unit: the unit to convert to
@@ -188,7 +188,7 @@ class Measurement:
         value, unit = self.get_tuple(unit)
         return f"{value}{unit.value[0]}"
 
-    def get_svg(self, unit: Optional[Unit] = None) -> str:
+    def get_svg(self, unit: Unit | None = None) -> str:
         """Get the measurement in the specified unit as it would be written in svg.
 
         :param optional unit: the unit to convert to
@@ -197,11 +197,11 @@ class Measurement:
         Rounds values to 6 decimal places as recommended by svg guidance online.
         Higher precision just changes file size without imroving quality.
         """
-        value, unit = self.get_tuple(unit)
-        value = format_number(self.get_value(unit))
-        return f"{value}{unit.value[0]}"
+        _, unit = self.get_tuple(unit)
+        value_as_str = format_number(self.get_value(unit))
+        return f"{value_as_str}{unit.value[0]}"
 
-    def __add__(self, other: "Measurement") -> "Measurement":
+    def __add__(self, other: Measurement) -> Measurement:
         """Add two measurements.
 
         :param other: the other measurement
@@ -211,7 +211,7 @@ class Measurement:
         result.value = self.value + other.value
         return result
 
-    def __sub__(self, other: "Measurement") -> "Measurement":
+    def __sub__(self, other: Measurement) -> Measurement:
         """Subtract two measurements.
 
         :param other: the other measurement
@@ -221,7 +221,7 @@ class Measurement:
         result.value = self.value - other.value
         return result
 
-    def __mul__(self, scalar: float) -> "Measurement":
+    def __mul__(self, scalar: float) -> Measurement:
         """Multiply a measurement by a scalar.
 
         :param scalar: the scalar to multiply by
@@ -231,7 +231,7 @@ class Measurement:
         result.value = self.value * scalar
         return result
 
-    def __rmul__(self, scalar: float) -> "Measurement":
+    def __rmul__(self, scalar: float) -> Measurement:
         """Multiply a measurement by a scalar.
 
         :param scalar: the scalar to multiply by
@@ -239,7 +239,7 @@ class Measurement:
         """
         return self.__mul__(scalar)
 
-    def __truediv__(self, scalar: float) -> "Measurement":
+    def __truediv__(self, scalar: float) -> Measurement:
         """Divide a measurement by a scalar.
 
         :param scalar: the scalar to divide by
